@@ -1,15 +1,13 @@
 use crate::{
-    body,
+    body::{self, Bytes, HttpBody},
     response::{IntoResponse, Response},
     BoxError, Error,
 };
-use bytes::Bytes;
 use futures_util::{
     ready,
     stream::{self, TryStream},
 };
 use http::HeaderMap;
-use http_body::Body;
 use pin_project_lite::pin_project;
 use std::{
     fmt,
@@ -98,7 +96,7 @@ impl<S> fmt::Debug for StreamBody<S> {
     }
 }
 
-impl<S> Body for StreamBody<S>
+impl<S> HttpBody for StreamBody<S>
 where
     S: TryStream,
     S::Ok: Into<Bytes>,
