@@ -2,7 +2,7 @@
 
 use self::{future::RouterFuture, not_found::NotFound};
 use crate::{
-    body::{boxed, Body},
+    body::{boxed, Body, Bytes, HttpBody},
     extract::{
         connect_info::{Connected, IntoMakeServiceWithConnectInfo},
         MatchedPath, OriginalUri,
@@ -12,7 +12,6 @@ use crate::{
     util::{try_downcast, ByteStr, PercentDecodedByteStr},
     BoxError,
 };
-use bytes::Bytes;
 use http::{Request, StatusCode, Uri};
 use std::{
     borrow::Cow,
@@ -48,13 +47,18 @@ pub use self::method_routing::{
 };
 
 #[derive(Clone, Copy, Debug, PartialEq, Eq, PartialOrd, Ord, Hash)]
-struct RouteId(u64);
+struct RouteId(u32);
 
 impl RouteId {
     fn next() -> Self {
-        use std::sync::atomic::{AtomicU64, Ordering};
-        static ID: AtomicU64 = AtomicU64::new(0);
-        Self(ID.fetch_add(1, Ordering::SeqCst))
+        use std::sync::atomic::{AtomicU32, Ordering};
+        // `AtomicU64` isn't supported on all platforms
+        static ID: AtomicU32 = AtomicU32::new(0);
+        let id = ID.fetch_add(1, Ordering::Relaxed);
+        if id == u32::MAX {
+            panic!("Over `u32::MAX` routes created. If you need this, please file an issue.");
+        }
+        Self(id)
     }
 }
 
@@ -273,7 +277,7 @@ where
             + Send
             + 'static,
         <L::Service as Service<Request<NewReqBody>>>::Future: Send + 'static,
-        NewResBody: http_body::Body<Data = Bytes> + Send + 'static,
+        NewResBody: HttpBody<Data = Bytes> + Send + 'static,
         NewResBody::Error: Into<BoxError>,
     {
         let layer = ServiceBuilder::new()
@@ -314,7 +318,7 @@ where
             + Send
             + 'static,
         <L::Service as Service<Request<B>>>::Future: Send + 'static,
-        NewResBody: http_body::Body<Data = Bytes> + Send + 'static,
+        NewResBody: HttpBody<Data = Bytes> + Send + 'static,
         NewResBody::Error: Into<BoxError>,
     {
         let layer = ServiceBuilder::new()
