@@ -1,5 +1,5 @@
-use crate::body::BoxBody;
-use http::{Request, Response, StatusCode};
+use crate::response::Response;
+use http::{Request, StatusCode};
 use std::{
     convert::Infallible,
     future::ready,
@@ -12,15 +12,15 @@ use tower_service::Service;
 /// This is used as the bottom service in a method router. You shouldn't have to
 /// use it manually.
 #[derive(Clone, Copy, Debug)]
-pub(crate) struct NotFound;
+pub(super) struct NotFound;
 
 impl<B> Service<Request<B>> for NotFound
 where
     B: Send + 'static,
 {
-    type Response = Response<BoxBody>;
+    type Response = Response;
     type Error = Infallible;
-    type Future = std::future::Ready<Result<Response<BoxBody>, Self::Error>>;
+    type Future = std::future::Ready<Result<Response, Self::Error>>;
 
     #[inline]
     fn poll_ready(&mut self, _cx: &mut Context<'_>) -> Poll<Result<(), Self::Error>> {
