@@ -1,4 +1,5 @@
 use crate::{
+    body::{Bytes, Empty},
     error_handling::HandleErrorLayer,
     extract::{self, Path},
     handler::Handler,
@@ -7,7 +8,6 @@ use crate::{
     test_helpers::*,
     BoxError, Json, Router,
 };
-use bytes::Bytes;
 use http::{Method, Request, Response, StatusCode, Uri};
 use hyper::Body;
 use serde::Deserialize;
@@ -234,7 +234,7 @@ async fn wrong_method_service() {
     struct Svc;
 
     impl<R> Service<R> for Svc {
-        type Response = Response<http_body::Empty<Bytes>>;
+        type Response = Response<Empty<Bytes>>;
         type Error = Infallible;
         type Future = Ready<Result<Self::Response, Self::Error>>;
 
@@ -243,7 +243,7 @@ async fn wrong_method_service() {
         }
 
         fn call(&mut self, _req: R) -> Self::Future {
-            ready(Ok(Response::new(http_body::Empty::new())))
+            ready(Ok(Response::new(Empty::new())))
         }
     }
 
